<TS language="nl_NL" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>Klik met de rechter muisknop om dit adres of label te veranderen</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>Maak een nieuw adres aan</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nieuw</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Kopieer het geselecteerde adres naar het klembord</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopieren</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>S&amp;luiten</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Verwijder het geselecteerde adres uit de lijst</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Exporteer de data in dit tab naar een bestand</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Exporteer</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Verwijderen</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>Selecteer het adres om munten naar toe te sturen.</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>Selecteer het adres om munten mee te ontvangen.</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>S&amp;electeren</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>Verzendadres</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>Ontvangstadres</translation>
    </message>
    <message>
        <source>These are your Litecoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>Dit zijn uw Litecoin adressen voor het versturen van betalingen. Controleer altijd het bedrag en het ontvangstadres voordat u munten verstuurd.</translation>
    </message>
    <message>
        <source>These are your Litecoin addresses for receiving payments. It is recommended to use a new receiving address for each transaction.</source>
        <translation>Dit zijn uw Litecoin adressen voor het ontvangen van betalingen. Het wordt aanbevolen om voor elke transactie een nieuw ontvangstadres te gebruiken.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp;Adres Kopiëren</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>&amp;Label Kopieren</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Bewerken</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>Adreslijst Exporteren</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Komma gescheiden bestand (*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Exporteren Mislukt</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>Er was een fout bij het opslaan van de adreslijst naar %1. Probeer het opnieuw.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Label</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adres</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(geen label)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Wachtwoord scherm</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Voer wachtwoord in</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Nieuw wachtwoord</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Herhaal nieuw wachtwoord</translation>
    </message>
    <message>
        <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>Voer je nieuwe wachtwoord in je portemonnee in.&lt;br/&gt;Gebruik een wachtwoord van &lt;b&gt;tien of meer willekeurige karakters&lt;/b&gt;, of &lt;b&gt;acht of meer woorden&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Versleutel portemonnee</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Deze actie heeft je wachtwoord nodig om je portemonnee te ontgrendelen</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Ontgrendel portemonnee</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>Deze actie heeft je wachtwoord nodig om je portemonnee te decoderen.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>Decodeer portemonnee</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Verander wachtwoord</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase to the wallet.</source>
        <translation>Voer het oude en nieuwe wachtwoord in voor de portemonnee.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Bevestig portemonnee versleuteling</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR LITECOINS&lt;/b&gt;!</source>
        <translation>Waarschuwing: Als je je portemonnee versleutelt en je wachtwoord kwijtraakt, raak je &lt;b&gt;AL JE LITECOINS KWIJT&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Weet je zeker dat je je portemonnee wilt versleutelen?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Portemonnee versleuteld</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>BELANGRIJK: Alle vorige backups die je hebt gemaakt van het portemonnee bestand moeten vervangen worden door het nieuwe gemaakte versleutelde portemonnee bestand. Voor beveiligingsredenen zullen vorige backups van het niet versleutelde portemonnee bestand niet meer werken zodra je gebruik maakt van de nieuwe versleutelde portemonnee.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Portemonnee versleutelen mislukt</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Portemonnee versleutelen mislukt vanwege een interne fout. Je portemonnee is niet versleuteld.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>De opgegeven wachtwoorden zijn niet identiek.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Portemonnee ontgrendelen mislukt</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Het ingevulde wachtwoord voor het ontsleutelen van de portemonnee is niet correct.</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>Ontgrendelen van de portemonnee mislukt</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Portemonnee wachtwoord met succes veranderd.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Waarschuwing: Caps Lock staat aan!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation>IP/Netmask</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation>Geblokkeerd Tot</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Signeer &amp;bericht</translation>
    </message>
    <message>
        <source>Synchronizing with network...</source>
        <translation>Synchroniseren met het netwerk...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Overzicht</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Toon algemeen overzicht van portemonnee</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;Transacties</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Door transactiegeschiedenis bladeren</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>Exit</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Applicatie sluiten</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation>&amp;Over %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation>Toon informatie over %1</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Over &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>Toon informatie over Qt</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Opties...</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation>Configuratieopties aanpassen voor%1</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Portemonnee Versleutelen...</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet...</source>
        <translation>&amp;Portemonnee Backuppen</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Wachtwoord Veranderen</translation>
    </message>
    <message>
        <source>Open &amp;URI...</source>
        <translation>Open &amp;URL...</translation>
    </message>
    <message>
        <source>Click to disable network activity.</source>
        <translation>Klik om netwerk activiteit uit te zetten.</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <translation>Netwerk activiteit uitgeschakeld.</translation>
    </message>
    <message>
        <source>Click to enable network activity again.</source>
        <translation>Klik om netwerk activiteit aan te zetten.</translation>
    </message>
    <message>
        <source>Syncing Headers (%1%)...</source>
        <translation>Headers synchroniseren (%1%)...</translation>
    </message>
    <message>
        <source>Reindexing blocks on disk...</source>
        <translation>Blokken op schijf herindexeren...</translation>
    </message>
    <message>
        <source>Send coins to a Litecoin address</source>
        <translation>Verstuur coins naar een Litecoin adres</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation>Back-up portemonnee naar een andere locatie</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Verander het wachtwoord die gebruikt wordt voor de portemonnee versleuteling</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>&amp;Debug scherm</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Open debugging en diagnostisch console</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Bericht verifiëren</translation>
    </message>
    <message>
        <source>Litecoin</source>
        <translation>Litecoin</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Versturen</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Ontvangen</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Tonen / Verbergen</translation>
    </message>
    <message>
        <source>Show or hide the main Window</source>
        <translation>Toon of verberg het hoofd scherm</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation>Versleutel de privé sleutels die bij je portemonnee horen</translation>
    </message>
    <message>
        <source>Sign messages with your Litecoin addresses to prove you own them</source>
        <translation>Signeer berichten met je Litecoin adres om te bewijzen dat ze van jou zijn</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Litecoin addresses</source>
        <translation>Verifieer berichten om er zeker van te zijn dat ze met specifieke Litecoin adressen ondertekent zijn</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Bestand</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Instellingen</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Help</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation>Tabs taakbalk</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and litecoin: URIs)</source>
        <translation>Betalingen aanvragen (genereert QR codes en litecoin: URI's)</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation>Toon de lijst van gebruikte verzend adressen en labels</translation>
    </message>
    <message>
        <source>Show the list of used receiving addresses and labels</source>
        <translation>Toon de lijst van gebruikte ontvangst adressen en labels</translation>
    </message>
    <message>
        <source>Open a litecoin: URI or payment request</source>
        <translation>Open een litecoin: URI of betaalverzoek</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation>&amp;Commando-regel opties</translation>
    </message>
    <message>
        <source>Indexing blocks on disk...</source>
        <translation>Blokken op schijf indexeren</translation>
    </message>
    <message>
        <source>Processing blocks on disk...</source>
        <translation>Blokken op schijf verwerken</translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation>%1 achter</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation>Laatst ontvangen blok is gegenereert %1 geleden</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation>Transacties hierna zullen niet zichtbaar zijn.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Waarschuwing</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informatie</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Up to date</translation>
    </message>
    <message>
        <source>Show the %1 help message to get a list with possible Litecoin command-line options</source>
        <translation>Open het %1 help bericht om een lijst met Litecoin commando-regel opties te krijgen</translation>
    </message>
    <message>
        <source>%1 client</source>
        <translation>%1 client</translation>
    </message>
    <message>
        <source>Connecting to peers...</source>
        <translation>Verbinding maken met peers...</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Inhalen...</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation>Datum: %1
</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation>Bedrag: %1
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation>Type: %1
</translation>
    </message>
    <message>
        <source>Label: %1
</source>
        <translation>Label: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation>Adres: %1
</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Transactie verzonden</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Binnenkomende transactie</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;enabled&lt;/b&gt;</source>
        <translation>HD sleutel generatie &lt;b&gt;geactiveerd&lt;/b&gt;</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;disabled&lt;/b&gt;</source>
        <translation>HD sleutel generatie &lt;b&gt;gedeactiveerd&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation>Portemonnee is &lt;b&gt;versleuteld&lt;/b&gt; en op dit moment &lt;b&gt;ontgrendeld&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Portemonnee is &lt;b&gt;versleuteld&lt;/b&gt; op dit moment &lt;b&gt;vergrendeld&lt;/b&gt;</translation>
    </message>
    <message>
        <source>A fatal error occurred. Litecoin can no longer continue safely and will quit.</source>
        <translation>Een fatale error is voorgekomen. Litecoin kan niet langer veilig verder gaan en sluit daardoor af.</translation>
    </message>
</context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Coin Selection</source>
        <translation>Coin Selectie</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Hoeveelheid:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Bytes:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Bedrag:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Fooi:</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>Dust:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Na Fooi:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Wisselgeld:</translation>
    </message>
    <message>
        <source>(un)select all</source>
        <translation>(de)selecteer alles</translation>
    </message>
    <message>
        <source>Tree mode</source>
        <translation>Tree modus</translation>
    </message>
    <message>
        <source>List mode</source>
        <translation>Lijst modus</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Bedrag</translation>
    </message>
    <message>
        <source>Received with label</source>
        <translation>Ontvangen met label</translation>
    </message>
    <message>
        <source>Received with address</source>
        <translation>Ontvangen met adres</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Bevestigingen</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Bevestigd</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Kopieer adres</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopieer label</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopieer bedrag</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Kopieer transactie ID</translation>
    </message>
    <message>
        <source>Lock unspent</source>
        <translation>Vergrendel niet uitgegeven</translation>
    </message>
    <message>
        <source>Unlock unspent</source>
        <translation>Ontgrendel niet uitgegeven</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Kopieer hoeveelheid</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Kopieer fooi</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Kopieer na fooi</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Kopieer bytes</translation>
    </message>
    <message>
        <source>Copy dust</source>
        <translation>Kopieer dust</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Kopieer wisselgeld</translation>
    </message>
    <message>
        <source>(%1 locked)</source>
        <translation>(%1 vergrendeld)</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>ja</translation>
    </message>
    <message>
        <source>no</source>
        <translation>nee</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(geen label)</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Litecoin</source>
        <translation>Litecoin</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Use separate SOCKS&amp;5 proxy to reach peers via Tor hidden services:</source>
        <translation>Gebruike aparte SOCKS&amp;5 proxy om peers te bereiken via Tor hidden services</translation>
    </message>
    <message>
        <source>Hide the icon from the system tray.</source>
        <translation>Verberg het icoontje van de taakbalk</translation>
    </message>
    <message>
        <source>Open Configuration File</source>
        <translation>Open Configuratie Bestand</translation>
    </message>
    <message>
        <source>Expert</source>
        <translation>Expert</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Poort mappen met &amp;UPnP</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Tor</source>
        <translation>Tor</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>Het ingegeven proxy adres is ongeldig</translation>
    </message>
</context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Available:</source>
        <translation>Beschikbaar:</translation>
    </message>
    <message>
        <source>Balances</source>
        <translation>Saldi</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>Totaal:</translation>
    </message>
    <message>
        <source>Recent transactions</source>
        <translation>Recente transacties</translation>
    </message>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>Bedrag</translation>
    </message>
    <message>
        <source>%1 and %2</source>
        <translation>%1 en %2</translation>
    </message>
    </context>
<context>
    <name>QObject::QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>Copy label</source>
        <translation>Kopieer label</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopieer bedrag</translation>
    </message>
</context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address</source>
        <translation>Adres</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Bedrag</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Label</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Portemonnee</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Label</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(geen label)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Hoeveelheid:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Bytes:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Bedrag:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Fooi:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Na Fooi:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Wisselgeld:</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>Dust:</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Kopieer hoeveelheid</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopieer bedrag</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Kopieer fooi</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Kopieer na fooi</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Kopieer bytes</translation>
    </message>
    <message>
        <source>Copy dust</source>
        <translation>Kopieer dust</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Kopieer wisselgeld</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(geen label)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Bedrag</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Label</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(geen label)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Copy address</source>
        <translation>Kopieer adres</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopieer label</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopieer bedrag</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Kopieer transactie ID</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Komma gescheiden bestand (*.csv)</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Bevestigd</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Label</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adres</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Exporteren Mislukt</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Exporteer</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Exporteer de data in dit tab naar een bestand</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Information</source>
        <translation>Informatie</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Waarschuwing</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
</context>
</TS>